@@ -1,10 +1,11 @@
 package Pod::Query;
 
-use 5.030;
+use v5.24;    # Postfix defef :)
 use strict;
 use warnings;
 use FindBin qw/ $RealBin /;
-use lib "$RealBin/Pod-LOL/lib";
+
+# use lib "$RealBin/Pod-LOL/lib";
 use Mojo::Base qw/ -base -signatures /;
 use Mojo::Util qw/ dumper class_to_path /;
 use Mojo::ByteStream qw/ b/;
@@ -19,11 +20,11 @@ Pod::Query - Query pod documents
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION       = '0.02';
+our $VERSION       = '0.03';
 our $DEBUG_TREE    = 0;
 our $DEBUG_FIND    = 0;
 our $DEBUG_INVERT  = 0;
@@ -96,7 +97,7 @@ Inline (Debugging)
 This module takes a class name, extracts the POD
 and provides methods to query specific information.
 
-=head1 METHODS
+=head1 SUBROUTINES/METHODS
 
 =head2 new
 
@@ -127,7 +128,7 @@ sub new ( $class, $pod_class, $path_only = 0 ) {
          # Normally =for and =begin would otherwise be skipped.
          $parser->accept_targets( '*' );
 
-         $parser->parse_file( $s->path )->root;
+         $parser->parse_file( $s->path )->{root};
       }
    };
 
@@ -969,17 +970,22 @@ sub get_term_width {
 }
 
 
+=head1 SEE ALSO
+
+L<App::Pod>
+
+L<Pod::LOL>
+
+L<Pod::Text>
+
+
 =head1 AUTHOR
 
 Tim Potapov, C<< <tim.potapov[AT]gmail.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-pod-query at rt.cpan.org>, or through
-the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Pod-Query>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
+Please report any bugs or feature requests to L<https://github.com/poti1/pod-query/issues>.
 
 
 =head1 SUPPORT
@@ -991,25 +997,13 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-=over 4
-
-=item * RT: CPAN's request tracker (report bugs here)
-
-L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Pod-Query>
-
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Pod-Query>
-
-=item * Search CPAN
-
-L<https://metacpan.org/release/Pod-Query>
-
-=back
+L<https://metacpan.org/pod/Pod::Query>
+L<https://github.com/poti1/pod-query>
 
 
 =head1 ACKNOWLEDGEMENTS
 
+TBD
 
 =head1 LICENSE AND COPYRIGHT
 
